<?php
namespace CreativeUnfoldContent;

use CreativeUnfoldContent\PageSettings\Page_Settings;
define( "BWDUF_ASFSK_ASSETS_PUBLIC_DIR_FILE", plugin_dir_url( __FILE__ ) . "assets/public" );
define( "BWDUF_ASFSK_ASSETS_ADMIN_DIR_FILE", plugin_dir_url( __FILE__ ) . "assets/admin" );

class Classbwdufunfoldcontent {

	private static $_instance = null;

	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

	public function bwduf_admin_editor_scripts() {
		add_filter( 'script_loader_tag', [ $this, 'bwduf_admin_editor_scripts_as_a_module' ], 10, 2 );
	}

	public function bwduf_admin_editor_scripts_as_a_module( $tag, $handle ) {
		if ( 'bwduf_the_contact_form_editor' === $handle ) {
			$tag = str_replace( '<script', '<script type="module"', $tag );
		}

		return $tag;
	}

	private function include_widgets_files() {
		require_once( __DIR__ . '/widgets/bwduf-unfoldcontent.php' );
	}

	public function bwduf_register_widgets() {
		// Its is now safe to include Widgets files
		$this->include_widgets_files();

		// Register Widgets
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\bwdufUnfoldcontent() );
	}

	private function add_page_settings_controls() {
		require_once( __DIR__ . '/page-settings/bwduf-unfold-content-manager.php' );
		new Page_Settings();
	}

	// Register Category
	function bwduf_add_elementor_widget_categories( $elements_manager ) {

		$elements_manager->add_category(
			'bwduf-unfold-content-category',
			[
				'title' => esc_html__( 'Unfold Content', 'bwduf-circle-progressbar' ),
				'icon' => 'eicon-person',
			]
		);
	}
	public function bwduf_all_assets_for_the_public(){
		wp_enqueue_script( 'bwduf-interactive', plugin_dir_url( __FILE__ ) . 'assets/public/js/unfold-content.js', array('jquery'), '1.0', true );
		
		$all_css_js_file = array(
            'unfold-fontawesome' => array('bwduf_path_define'=>BWDUF_ASFSK_ASSETS_PUBLIC_DIR_FILE . '/css/all.min.css'),
            'main-unfold-style' => array('bwduf_path_define'=>BWDUF_ASFSK_ASSETS_PUBLIC_DIR_FILE . '/css/unfold-content.css'),
        );
        foreach($all_css_js_file as $handle => $fileinfo){
            wp_enqueue_style( $handle, $fileinfo['bwduf_path_define'], null, '1.0', 'all');
        }
	}
	public function bwduf_all_assets_for_elementor_editor_admin(){
		$all_css_js_file = array(
            'admin-unfold-icon-style' => array('bwduf_path_admin_define'=>BWDUF_ASFSK_ASSETS_ADMIN_DIR_FILE . '/icon.css'),
        );
        foreach($all_css_js_file as $handle => $fileinfo){
            wp_enqueue_style( $handle, $fileinfo['bwduf_path_admin_define'], null, '1.0', 'all');
        }
	}

	public function __construct() {
		// For public assets
		add_action('wp_enqueue_scripts', [$this, 'bwduf_all_assets_for_the_public']);

		// For Elementor Editor
		add_action('elementor/editor/before_enqueue_scripts', [$this, 'bwduf_all_assets_for_elementor_editor_admin']);
		
		// Register Category
		add_action( 'elementor/elements/categories_registered', [ $this, 'bwduf_add_elementor_widget_categories' ] );

		// Register widgets
		add_action( 'elementor/widgets/register', [ $this, 'bwduf_register_widgets' ] );

		// Register editor scripts
		add_action( 'elementor/editor/after_enqueue_scripts', [ $this, 'bwduf_admin_editor_scripts' ] );
		
		$this->add_page_settings_controls();
	}
}

// Instantiate Plugin Class
Classbwdufunfoldcontent::instance();